==> heptapod-rails-0.23.0.tar.gz: heptapod-rails-0.23.0/doc/administration/whats-new.md <==
---
stage: Growth
group: Adoption
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/engineering/ux/technical-writing/#assignments
---

# What's new **(FREE)**

With each monthly release, GitLab includes some of the highlights from the last 10
GitLab versions in the **What's new** feature. To access it:

1. In the top navigation bar, select the **{question}** icon.
1. Select **What's new** from the menu.

The **What's new** describes new features available in multiple
[GitLab tiers](https://about.gitlab.com/pricing). While all users can see the
feature list, the feature list is tailored to your subscription type:

- Features only available to self-managed installations are not shown on GitLab.com.
- Features only available on GitLab.com are not shown to self-managed installations.

## Self-managed installations

Due to our release post process, the content for **What's new** is not yet finalized
when a new version (`.0` release) is cut. The updated **What's new** is included
in the first patch release, such as `13.10.1`.

## Configure What's new variant

You can configure the What's new variant:

1. Navigate to **Admin Area > Settings > Preferences**, then expand **What's new**.
1. Choose one of the following options:

   | Option | Description |
   | ------ | ----------- |
   | Enable What's new: All tiers | What's new presents new features from all tiers to help you keep track of all new features. |
   | Enable What's new: Current tier only | What's new presents new features for your current subscription tier, while hiding new features not available to your subscription tier. |
   | Disable What's new | What's new is disabled and can no longer be viewed. |

1. Save your changes.

==> heptapod-rails-0.24.0rc1.tar.gz: heptapod-rails-0.24.0rc1/doc/administration/whats-new.md <==
---
stage: Growth
group: Adoption
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/engineering/ux/technical-writing/#assignments
---

# What's new **(FREE)**

With each monthly release, GitLab includes some of the highlights from the last 10
GitLab versions in the **What's new** feature. To access it:

1. In the top navigation bar, select the **{question}** icon.
1. Select **What's new** from the menu.

The **What's new** describes new features available in multiple
[GitLab tiers](https://about.gitlab.com/pricing). While all users can see the
feature list, the feature list is tailored to your subscription type:

- Features only available to self-managed installations are not shown on GitLab.com.
- Features only available on GitLab.com are not shown to self-managed installations.

## Self-managed installations

Due to our release post process, the content for **What's new** is not yet finalized
when a new version (`.0` release) is cut. The updated **What's new** is included
in the first patch release, such as `13.10.1`.

## Configure What's new variant

You can configure the What's new variant:

1. On the top bar, select **Menu >** **{admin}** **Admin**.
1. On the left sidebar, select **Settings > Preferences**, then expand **What's new**.
1. Choose one of the following options:

   | Option | Description |
   | ------ | ----------- |
   | Enable What's new: All tiers | What's new presents new features from all tiers to help you keep track of all new features. |
   | Enable What's new: Current tier only | What's new presents new features for your current subscription tier, while hiding new features not available to your subscription tier. |
   | Disable What's new | What's new is disabled and can no longer be viewed. |

1. Save your changes.
